<?php
/*
 * This class is an example how to implement Checkout API
 */
class Checkout {
	private $version="0001";
	private $language="FI";
	private $country="FIN";
	private $currency="EUR";
	private $device="1";
	private $content="1";
	private $type="0";
	private $algorithm="2";
	private $merchant="";
	private $password="";
	private $stamp=0;
	private $amount=0;
	private $reference="";
	private $message="";
	private $return="";
	private $cancel="";
	private $reject="";
	private $delayed="";
	private $delivery_date="";
	private $firstname="";
	private $familyname="";
	private $address="";
	private $postcode="";
	private $postoffice="";
	private $status="";
	
	public function __construct($merchant,$password) {
		$this->merchant=$merchant; // merchant id
		$this->password=$password; // security key (about 80 chars)
	}

	/*
 	 * generates MAC and prepares values for creating payment
	 */	
	public function generateCheckout($data) {
		foreach($data as $key => $value) {
			$this->{$key}=$value;
		}
		$mac=strtoupper(md5("{$this->version}+{$this->stamp}+{$this->amount}+{$this->reference}+{$this->message}+{$this->language}+{$this->merchant}+{$this->return}+{$this->cancel}+{$this->reject}+{$this->delayed}+{$this->country}+{$this->currency}+{$this->device}+{$this->content}+{$this->type}+{$this->algorithm}+{$this->delivery_date}+{$this->firstname}+{$this->familyname}+{$this->address}+{$this->postcode}+{$this->postoffice}+{$this->password}"));
		$post['VERSION']=$this->version;
		$post['STAMP']=$this->stamp;
		$post['AMOUNT']=$this->amount;
		$post['REFERENCE']=$this->reference;
		$post['MESSAGE']=$this->message;
		$post['LANGUAGE']=$this->language;
		$post['MERCHANT']=$this->merchant;
		$post['RETURN']=$this->return;
		$post['CANCEL']=$this->cancel;
		$post['REJECT']=$this->reject;
		$post['DELAYED']=$this->delayed;
		$post['COUNTRY']=$this->country;
		$post['CURRENCY']=$this->currency;
		$post['DEVICE']=$this->device;
		$post['CONTENT']=$this->content;
		$post['TYPE']=$this->type;
		$post['ALGORITHM']=$this->algorithm;
		$post['DELIVERY_DATE']=$this->delivery_date;
		$post['FIRSTNAME']=$this->firstname;
		$post['FAMILYNAME']=$this->familyname;
		$post['ADDRESS']=$this->address;
		$post['POSTCODE']=$this->postcode;
		$post['POSTOFFICE']=$this->postoffice;
		$post['MAC']=$mac;

		if($this->device == 10){
			$post['EMAIL']=$this->email;
		}
		return $post;
	}
	
	/*
	 * returns payment information in XML
	 */
	public function getCheckoutXML($data) {
		$this->device="10";
		return $this->sendPost($this->generateCheckout($data));
	}
	
	private function sendPost($post) {
		// implementation uses fsockopen so that it will work
		// everywhere. Good alternatives are file_get_contents, curl

		$data="";
		foreach($post as $key => $value) {
		  	$data.=urlencode($key)."=".urlencode($value)."&";
		}
		
		$fp = fsockopen("ssl://payment.checkout.fi", 443);
		fputs($fp, "POST / HTTP/1.0\r\n");
		fputs($fp, "Host: payment.checkout.fi\r\n");
		fputs($fp, "Content-Type: application/x-www-form-urlencoded\r\n");
		fputs($fp, "User-Agent: Checkout-poster/1.1\r\n");
		fputs($fp, "Content-Length: " . strlen($data) . "\r\n");
		fputs($fp, "Connection: close\r\n\r\n");
		fputs($fp, $data."\r\n\r\n");
	
		while (!feof($fp)) $sent .= fgets($fp,128);
		fclose($fp);
		$tmp=split("\r\n\r\n",$sent,2);
		$return=split("\n",$tmp[1],2);
		return $return[1];
	}
	
	public function validateCheckout($data) {
		$keys=array("VERSION","STAMP","REFERENCE","PAYMENT","STATUS","ALGORITHM","MAC");

		$mac="";
		foreach($data as $key => $value) {
			if(!in_array($key,$keys)) continue;

			$key=strtolower($key);
			if($key!="mac") $this->{$key}=$value;
			else $mac=$value;
		}
		$generatedMac=strtoupper(md5("{$this->password}&{$this->version}&{$this->stamp}&{$this->reference}&{$this->payment}&{$this->status}&{$this->algorithm}"));
		if($mac==$generatedMac) {
			return true;
		} 
		return false;
	}
	
	public function isPaid() {
		if($this->status!="") {
			if(in_array($this->status,array(2,4,5,6,7,8,9,10))) 
				return true;
		}
		return false;
	}
}  // class Checkout

$co=new Checkout(430219,"0wQdggm4dSsr6T01wwqxqbZhGSaa3TDLforQZwDF262vPiX072KgChBwh8ldGJknrK5MCKQIZlpRM8vyjAGTk62j"); // merchantID and securitykey (normally about 80 chars)


if(isset($_GET['MAC'])) { // if we are returning from payment
	echo '<h1>Checkout API example</h1>';
	echo '<p><a href="xml2.txt">View sourcecode</a></p>';
	if($co->validateCheckout($_GET)) {
		echo("<p>Checkout transaction MAC CHECK OK, payment status =  ");
		if($co->isPaid()) {
			echo("Paid.");
		} else {
			echo("Not paid.");
		}
		echo ("</p>");
	} else {
		echo("<p>Checkout transaction MAC CHECK Failed.</p>");	
	}
	echo "<p><a href='xml2.php'>Start again</a></p>";
	exit;
}

// Order information
$coData=array();
$coData["stamp"]=time(); // unique timestamp
$coData["reference"]="12344";
$coData["message"]="Huonekalutilaus\nPaljon puita, lehtiä ja muttereita";
$coData["return"]="http://www.kynnetjakauneus.fi";
$coData["amount"]="1000"; // price in cents
$coData["delivery_date"]=date("Ymd");
$coData["firstname"]="Tero";
$coData["familyname"]="Testaaja";
$coData["address"]="Ääkköstie 5b3\nKulmaravintolan yläkerta";
$coData["postcode"]="33100";
$coData["postoffice"]="Tampere";
$coData["email"]="tero@testaaja.fi"; // buyers email-address
$post=$co->generateCheckout($coData); // generate payment button - deprecated method, use only if XML method is not possible

// XML mode with bank buttons
$coData['stamp']=time()+1; // update stamp, so it's different payment request than the deprecated method
$return=$co->getCheckoutXML($coData); // get payment button data
$xml=simplexml_load_string($return);

// paymentURL link is used if a payer somehow manages to fail paying. You can
// save it to the webstore and later (if needed) send it by email.
$link=$xml->paymentURL;

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html><head><title>Checkout maksudemo</title></head>
<style>
.C1 {
 width: 180px;
 height: 120px;
 border: 1pt solid #a0a0a0;
 display: block;
 float: left;
 margin: 7px;
 -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
 clear: none;
 padding: 0;
}

.C1:hover {
 background-color: #f0f0f0;
 border-color: black;
}

.C1 form {
 width: 180px;height: 120px;
}
.C1 form span {
 display:table-cell; vertical-align:middle;
 height: 92px;
 width: 180px;
}
.C1 form span input {
 margin-left: auto;
 margin-right: auto;
 display: block;
 border: 1pt solid #f2f2f2;
 -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
 padding: 5px;
 background-color: white;
}
.C1:hover form span input {
 border: 1pt solid black;
}
.C1 div {
 text-align: center;
 font-family: arial;
 font-size: 8pt;
}
</style>
<body>
<h1>Checkout API example</h1>
<a href="xml2.txt">View sourcecode</a>
<h2>Maksunapit verkkosivulle, suositeltu tapa / XML API, Recommended method</h2>

<?php foreach($xml->payments->payment->banks as $bankX):?>
 <?php foreach($bankX as $bank):?>
  <div class='C1'>
   <form action='<?=$bank['url'];?>' method='post'>
    <?php foreach($bank as $key => $value):?>
     <input type='hidden' name='<?=$key;?>' value='<?=$value;?>' />
    <?php endforeach;?>
    <span><input type='image' src='<?=$bank['icon'];?>' /></span>
    <div><?=$bank['name'];?></div>
   </form>
  </div>
 <?php endforeach;?>
<?php endforeach;?>
<hr style='clear: both;' />
<h2>Erillinen maksusivu / vanha tapa / deprecated method</h2>
<form action='https://payment.checkout.fi/' method='post'>
 <?php foreach($post as $field => $value):?>
  <input type='hidden' name='<?=$field;?>' value='<?=$value;?>' />
 <?php endforeach;?>
 <input type='submit' value='Siirry maksusivulle' />
</form>


</body></html>

